﻿using Accordion.Model;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

// The User Control item template is documented at http://go.microsoft.com/fwlink/?LinkId=234236

namespace Accordion.Controls
{
    public sealed partial class InspectionItemListView : UserControl
    {
        public List<BooleanComboBoxItem> BooleanComboBoxItems = new List<BooleanComboBoxItem>();
        public InspectionItemListView()
        {
            BooleanComboBoxItems.Add(new BooleanComboBoxItem("", @"N\A"));
            BooleanComboBoxItems.Add(new BooleanComboBoxItem("true", "True"));
            BooleanComboBoxItems.Add(new BooleanComboBoxItem("false", "False"));

            this.InitializeComponent();
            this.DataContext = this;
        }

        public void SetItemsSource(ObservableCollection<InspectionItem> inspectionItems)
        {
            //var inspectionItemsGrouped = from inspectionItem in inspectionItems
            //                             group inspectionItem by inspectionItem.SubCategory into grp
            //                             select grp;
            var inspectionItemsGrouped = inspectionItems.GroupBy(item => item.SubCategory).Select(g => new
            {
                SubCategory = g.Key,
                Items = g.ToList(),
                CountGroup = g.Count(),
                ValidCount = g.Sum(c => c.IsValid ? 1 : 0).ToString()
            }).ToList();

            InspectionItemsViewSource.Source = inspectionItemsGrouped;
        }

        private void AutoSuggestBox_TextChanged(AutoSuggestBox sender, AutoSuggestBoxTextChangedEventArgs args)
        {
            var items = ((InspectionItem)sender.DataContext).AvailableOptions;

            var filtered = from item in items
                           where item.Display.StartsWith(sender.Text, StringComparison.CurrentCultureIgnoreCase)
                           select item;

            if (filtered.Count() != 0)
            {
                sender.ItemsSource = filtered.ToList();
                sender.DisplayMemberPath = "Display";
            }
            else
            {
                sender.ItemsSource = new List<AvailableOption>();
            }
        }

        private void AutoSuggest_SuggestionChosen(AutoSuggestBox sender, AutoSuggestBoxSuggestionChosenEventArgs args)
        {
            // TODO: Should the NewVale be set to the AvailableOptionValue or Display
            sender.Text = ((AvailableOption)args.SelectedItem).Display;
            ((InspectionItem)sender.DataContext).NewValue = sender.Text;
        }

        private void ComboBox_Loaded(object sender, RoutedEventArgs e)
        {
            var comboBox = ((ComboBox)sender);

            comboBox.ItemsSource = BooleanComboBoxItems;
            comboBox.DisplayMemberPath = "Display";
            comboBox.SelectedValuePath = "Value";

        }

        private void AutoSuggest_GotFocus(object sender, RoutedEventArgs e)
        {
        }

        private void AddCommentIcon_Tapped(object sender, TappedRoutedEventArgs e)
        {
    
        }

        private void RadioButton_Checked(object sender, RoutedEventArgs e)
        {
        
        }


    }

    public class BooleanComboBoxItem
    {
        public string Value { get; set; }

        public string Display { get; set; }

        public BooleanComboBoxItem(string value, string display)
        {
            Value = value;
            Display = display;
        }
    }
}