﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Windows.Data.Json;

using Windows.Storage;
using Windows.Storage.Compression;
using Windows.Storage.Streams;
using System.IO;
using System.IO.Compression;
using Windows.Foundation.Diagnostics;
using Accordion.Utilities;

namespace Accordion.Model
{
    public class InspectionComponent 
    {
        private const string inspectionComponentIdKey = "inspectionComponentId";
        private const string inspectionComponentTypeKey = "itemType";
        private const string inspectionMethodKey = "inspectionMethod";
        private const string inspectionItemsKey = "inspectionItems";
        private const string availableOptionCollectionsKey = "availableOptionCollections";

        private const string photoCollectionKey = "photoCollection";
        private const string zipNameKey = "zipName";

        private string componentId;
        private GdsObservableCollection<InspectionItem> inspectionItems;
        private Dictionary<string, AvailableOptionCollection> availableOptionCollections;



        public InspectionComponent()
        {
            componentId = string.Empty;
            inspectionItems = new GdsObservableCollection<InspectionItem>();
            InspectionItemsLoaded = false;
            //availableOptionCollection = new ObservableCollection<AvailableOptionCollection>();
            availableOptionCollections = new Dictionary<string, AvailableOptionCollection>();

        }

        public GdsObservableCollection<InspectionItem> InspectionItems
        {
            get { return inspectionItems; }
            set { inspectionItems = value; }
        }



        public string InspectionMethod { get; set; }

 
        public string ZipName { get; set; }

 
   
        public string ComponentId
        {
            get
            {
                return componentId;
            }
            set
            {
                if (value == null)
                {
                    throw new ArgumentNullException("value");
                }
                componentId = value;
            }
        }

        public int InspectionItemCount
        {
            get
            {
                //return inspectionItemCount;
                return inspectionItems.Count();
            }
        }



        public bool InspectionItemsLoaded { get; private set; }

        // Switching from ObservableCollection to Dictionary for easy lookups
        //public ObservableCollection<AvailableOptionCollection> AvailableOptionCollection
        public Dictionary<string, AvailableOptionCollection> AvailableOptionCollections
        {
            get
            {
                return availableOptionCollections;
            }
        }

        public InspectionComponent CopyFilteredOnCategory(string categoryName)
        {
            var filteredInspectionComponent = new InspectionComponent();
            filteredInspectionComponent.ComponentId = string.Format("{0} - {1}", ComponentId, categoryName);

            foreach (var item in this.InspectionItems)
            {
                if (item.MainCategory.Equals(categoryName))
                {
                    filteredInspectionComponent.InspectionItems.Add(item);
                }
            }

            return filteredInspectionComponent;
        }

        public InspectionComponent CopyOfFeaturesFilteredOnCategory(string categoryName)
        {
            var filteredFeatures = new InspectionComponent();
            filteredFeatures.ComponentId = string.Format("{0} - {1}", ComponentId, categoryName);

            var features = from item in InspectionItems
                           where item.SubCategory1.Equals("Features")
                           select item;

            features.ToList().ForEach(filteredFeatures.InspectionItems.Add);

            return filteredFeatures;
        }

        public IDictionary<string, int> CategoryOrder { get; set; }

 

        public bool IsDirty { get; set; }




        public string ComponentType { get; set; }


    }
}
